using System;
using System.Diagnostics;
using System.Web;

namespace PersistDemo 
{
	/// <summary>
	/// Global application object for persistence demo.
	/// </summary>
	public class Global : System.Web.HttpApplication
	{	
		/// <summary>
		/// Constructor for global object.
		/// </summary>
		public Global()
		{	
			InitializeComponent();
		}	
		/// <summary>
		/// Start the app.  Store any persistence values desired into the Application state collection.
		///	Then restore the static fields of any classes that use persistence.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void Application_Start(Object sender, EventArgs e)
		{
			// Example of pre-initializing the Application state collection with a value to 
			//	be given to specific page classes.
			PagePersister.SetPageField(Application,
										typeof(PersistPage),
										"sAppString",
										"this value is kept in the Application");
			//  Restore the static variables of the Global class and the PersistPage class.
			PagePersister.RestoreStatic(Application,typeof(Global));
			//  Restore the static variables of the all subclasses of the System.Web.UI.Page class.
			PagePersister.RestorePageStatics(Application);
		}
		/// <summary>
		/// Event called before page request processing begins.  Do any necessary persistence.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void Application_PreRequestHandlerExecute(Object sender, EventArgs e)
		{
			PagePersister.PersistPage(this,true);
		}
		/// <summary>
		/// Event called after all page processing ends.  Do any necessary persistence.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void Application_PostRequestHandlerExecute(Object sender, EventArgs e)
		{
			PagePersister.PersistPage(this,false);
		}
		/// <summary>
		/// A session is ending.  Walk its Session state collection and call Dispose() on any
		/// persisted fields that support IDisposable.
		/// </summary>
		/// <param name="sender"></param>
		/// <param name="e"></param>
		protected void Session_End(Object sender, EventArgs e)
		{
			PagePersister.SessionEnd(Session);
		}
			
		#region Web Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
		}
		#endregion
	
		/// <summary>
		/// Sample field persisted from web.config
		/// </summary>
		[PagePersist(PagePersistEnum.ePersistWebConfig)]
		protected static string sImageTempDirectory = "";
		
	}
}

