/*
Copyright  2002 Covansys

Permission to use, copy, modify, and distribute this software and its
documentation for any purpose is hereby granted without fee, provided that
the above copyright notice appears in all copies and that both that copyright
notice and this permission notice appear in supporting documentation. You are
not permitted to sell this software or any portion of this software without
permission and a suitable agreement with Covansys.

Covansys makes no representations about the suitability of this
software for any purpose. It is provided "as is" without express or implied
warranty.
*/


#include "stdafx.h"
#include "connect.h"
#include "stdlib.h"


bool SocketInit(void)
{
	WORD wVersionRequested;
	WSADATA wsaData;
	int err;
	wVersionRequested = MAKEWORD( 1, 1 );
	err = WSAStartup( wVersionRequested, &wsaData );

	if ( err != 0 )
	{
		::MessageBox (NULL, "WSAStartup failed\n" , "Message Box", 0);
		return false;
	}

	if ( LOBYTE( wsaData.wVersion ) != 1 ||
			HIBYTE( wsaData.wVersion ) != 1 )
	{
		::MessageBox (NULL, "Failed for WinSock DLL version 1.1\n" , "Message Box", 0);
		WSACleanup( );
		return false;
	}
	return true;
}
void SocketDeinit(void)
{
	WSACleanup( );
}

//
// Function: ConnectTo
//
// Description: Connect to the target through ethernet.
// If it connects successfully, returns the socket descriptor
// otherwise, it returns the value of INVALID_SOCKET.
//
// parameters:
// ipaddr: must specify the IP address in standard dot notation
// port: the port number of the scale application
//
SOCKET	ConnectTo(const char* ipaddr, int port)
{
	unsigned long	ulAddr;
	SOCKET			fd;
	SOCKADDR_IN		sin;
	int				iRet;

 	fd = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
	if (ERROR_SOCKETFD(fd))
	{
		::MessageBox (NULL, "Function socket() failed\n" , "Message Box", 0);
		return INVALID_SOCKET;
	}


	ulAddr = inet_addr(ipaddr);
	if (INADDR_NONE == ulAddr)
	{
        ::MessageBox (NULL, "Invalid internet address:\n" , "Message Box", 0);
		return INVALID_SOCKET;
	}
	sin.sin_family = AF_INET;
	sin.sin_port = htons(port);
	sin.sin_addr.s_addr = ulAddr;

	iRet = connect (fd, (LPSOCKADDR)&sin, sizeof (sin));
	if (ERROR_RETCODE(iRet))
	{
		::MessageBox (NULL, "Function connect() failed:\n" , "Message Box", 0);
		closesocket(fd);
		return INVALID_SOCKET;
	}
	return fd;
}
