import javax.xml.transform.*;
import javax.xml.transform.stream.*;
import java.io.*;

public class XMLQueryManager {

  // The source XML
  private Source _xmlSource = null;

  // The XSLT file template name
  private String _xslFileTemplate = null;


  // Constructor
  public XMLQueryManager(String xmlFile, String xslFile) throws Exception {

    _xmlSource = new StreamSource(new File(xmlFile));
    _xslFileTemplate = xslFile;

  }

  // The query method takes the query criteria and return the
  // result of the XSLT process
  public String query(String xslStatement) throws Exception {

    // Get a Source object for XSLT
    File xslFile = makeXSL(xslStatement);
    Source xslSource = new StreamSource(xslFile);

    // Create a Result object
    String resultFileName = "result" + System.currentTimeMillis() + ".html";
    Result result = new StreamResult(new File(resultFileName));

    // Use JAXP 1.1 XSLT Processor
    TransformerFactory factory = TransformerFactory.newInstance();
    Transformer trans = factory.newTransformer(xslSource);

    // Invoke the XSLT procesor
    trans.transform(_xmlSource,result);

    // Delete the temporary XSL file
    xslFile.delete();

    // Return the generated result as string
    return fileToString(resultFileName);

  }


  // This method makes the concrete XSL stylesheet starting
  // from the passed xslStatement (query criteria)
  private File makeXSL(String xslStatement) throws Exception {

    RandomAccessFile source = new RandomAccessFile(_xslFileTemplate,"r");
    byte v[] = new byte[(int)source.length()];
    source.readFully(v);
    String xslData = new String(v);

    xslData = replace(xslData,xslStatement);

    String filename = _xslFileTemplate.toString() + System.currentTimeMillis();

    RandomAccessFile target = new RandomAccessFile(filename,"rw");
    target.setLength(0L);
    target.writeBytes(xslData);

    source.close();
    target.close();

    return new File(filename);

  }

  // Read the contents of a file an put it in a string
  private String fileToString(String fileName) throws Exception {

    RandomAccessFile raf = new RandomAccessFile(fileName,"r");
    byte v[] = new byte[(int)raf.length()];
    raf.readFully(v);
    raf.close();

    (new File(fileName)).delete();

    return new String(v);

  }

  // Replace the $ symbol
  private String replace(String original, String inserted) {

    char ch = '\0';
    int i=0;
    for (;ch!='$';i++) ch=original.charAt(i);

    String firstPart = original.substring(0,i-1);
    return firstPart + inserted + original.substring(i,original.length());

  }

  // Main example
  public static void main(String a[]) throws Exception {

    System.out.println("Query started...");
    XMLQueryManager qm = new XMLQueryManager("employee.xml","employee.xsl");
    String result = qm.query("employees/employee[contains(surname,'Hill')]");
    System.out.println(result);


  }



}