using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using System.Diagnostics;

namespace PersistDemo
{
	/// <summary> 
	/// A test ASPX page to demonstrate the types of persistence possible with PagePersister.
	/// </summary>
	public class PersistPage : System.Web.UI.Page
	{
		/// <summary>
		/// Constructor for the persistence test page.  
		/// </summary>
		public PersistPage ()
		{
		}
		/// <summary>
		/// Page load event.  If not post-back, initialize the persisted fields; else
		///	verify that persistence worked.
		/// </summary>
		/// <param name="sender">Standard event generator</param>
		/// <param name="e">standard event arguments</param>
		private void Page_Load(object sender, System.EventArgs e)
		{
			int iElapsed = 0;
			DateTime dtNow = DateTime.Now;
			if ( IsPostBack )
			{
				bDebugOutput = CbxDebug.Checked;
				sSubcategoryLast = TbxSubcategory.Text;
				sCategoryLast = TbxCategory.Text;			
				TestPersistence();
				TimeSpan tsElapsed = dtNow.Subtract(dtLast);
				iElapsed = tsElapsed.Seconds;
			}
			else
			{
				string[] sa = {"First","Second", "Third", "Fourth"};
				arrayString = sa;
				dtLast = dtNow;
				TbxSubcategory.Text = sSubcategoryLast;
				TbxCategory.Text = sCategoryLast;
				CbxDebug.Checked = bDebugOutput;
				TbxPerPage.Text = nImagesPerPage.ToString();
				TbxApp.Text = sAppString;
				TbxConnect.Text = sConnectString;
			}
			++nVisit;
			TbxVisit.Text = nVisit.ToString();
			TbxElapsed.Text = iElapsed.ToString();
			dtLast = dtNow;
		}
		/// <summary>
		/// Test that the contents of the test array are correct.
		/// </summary>
		private void TestPersistence()
		{
			bPersistenceError = true;				
			if (arrayString[0] != "First" ||
				arrayString[1] != "Second" ||
				arrayString[2] != "Third" ||
				arrayString[3] != "Fourth" )
				return;
			bPersistenceError = false;				
		}
		/// <summary>
		/// Display an error if persistence failed.
		/// </summary>
		protected void RenderError()
		{
			if ( ! bPersistenceError )
				return;
			Response.Write("<H1>Persistence Failure!</H1>");	
		}

		#region Web Form Designer generated code
		override protected void OnInit(EventArgs e)
		{
			//
			// CODEGEN: This call is required by the ASP.NET Web Form Designer.
			//
			InitializeComponent();
			base.OnInit(e);
		}
		
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{    
			this.Load += new System.EventHandler(this.Page_Load);

		}
		#endregion

		protected System.Web.UI.WebControls.TextBox TbxSubcategory;
		protected System.Web.UI.WebControls.TextBox TbxCategory;
		protected System.Web.UI.WebControls.CheckBox CbxDebug;
		protected System.Web.UI.WebControls.TextBox TbxPerPage;
		protected System.Web.UI.WebControls.TextBox TbxConnect;
		protected System.Web.UI.WebControls.TextBox TbxVisit;
		protected System.Web.UI.WebControls.TextBox TbxApp;
		protected System.Web.UI.WebControls.Button ButnSubmit;
		protected System.Web.UI.WebControls.TextBox TbxElapsed;
								
		/// <summary>
		/// Unpersisted variable
		/// </summary>
		bool bPersistenceError = false;
								
		//  Variables persisted at the Session level
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected string[] arrayString;	
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected string sCategoryLast = "Initial Category";
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected string sSubcategoryLast = "Initial Subcategory";
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected bool bDebugOutput = true;
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected int nImagesPerPage = 4;
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected int nVisit = 0;
		[PagePersist(PagePersistEnum.ePersistSession)]		
		protected DateTime dtLast;
				
		/// <summary>
		/// Variable persisted in the web.config file
		/// </summary>
		[PagePersist(PagePersistEnum.ePersistWebConfig)]
		protected static readonly string sConnectString = "";

		/// <summary>
		/// Variable persisted in the Application state collection
		/// </summary>
		[PagePersist(PagePersistEnum.ePersistApplication)]		
		static protected string sAppString = "";		
	}
}
