/**
	14/05/2002
	@author		Bogdan Dorohonceanu
 */

package fn;

import java.awt.*;
import java.awt.event.*;
import java.lang.reflect.Method;

public class PanelFuzzyNumber extends Panel implements ItemListener, PanelValueListener {

	private Fuzzy fuzzy;
    private double min = 0.0, max = 5.0, step = 0.1;
    protected PanelValue pv[];
    protected CheckboxGroup rb;
    protected Checkbox rbTFN, rbTrFN;
    protected Label lName;

    public PanelFuzzyNumber(Fuzzy fuzzy, String name) {

        super(null);
        setSize(400,55);

		this.fuzzy = fuzzy;

        lName = new Label(name, Label.CENTER);
        lName.setFont(new Font("Dialog",Font.PLAIN,14));
        add(lName);
        lName.setBounds(0,20,30,20);

        rb = new CheckboxGroup();

        rbTFN = new Checkbox("TFN",rb, true);
        rbTFN.setFont(new Font("Dialog",Font.PLAIN,14));
        add(rbTFN);
        rbTFN.setBounds(35,7,50,20);

        rbTrFN = new Checkbox("TrFN",rb, false);
        rbTrFN.setFont(new Font("Dialog",Font.PLAIN,14));
        add(rbTrFN);
        rbTrFN.setBounds(35,33,50,20);

        pv = new PanelValue [4];
        for (int i = 0; i < 4; i++) {
            pv[i] = new PanelValue (min, max, step);
            if (i == 3) {
                pv[i].setVisible(false);
            }
            add(pv[i]);
            pv[i].setBounds(90+75*i,15,74,20);
            pv[i].addPanelValueListener(this);
        }

        rbTFN.addItemListener(this);
        rbTrFN.addItemListener(this);
    }

	public synchronized void panelValueChanged(PanelValueEvent event) {
		PanelValue p = (PanelValue) event.getSource();
		double d = event.getValue();
		int i = 0;
		while ((p != pv[i]) && (i < 4)) {
			i ++ ;
		}
		if ((i > 0) && (pv[i - 1].getValue() > d)) {
			pv[i - 1].setValue(d);
		}
		if ((i < 3) && (pv[i + 1].getValue() < d)) {
			pv[i + 1].setValue(d);
		}
		fuzzy.compute();
	}

    public void itemStateChanged(ItemEvent event) {
        Object source = event.getSource();
        if (source == rbTrFN) {
              clickedRbTrFN();
        }
        else
        if (source == rbTFN) {
              clickedRbTFN();
        }
    }

    public void clickedRbTFN() {
        if (pv[3].isVisible () == true) {
            pv[3].setVisible(false);
            fuzzy.compute();
        }
    }

    public void clickedRbTrFN() {
        if (pv[3].isVisible () == false) {
            pv[3].setVisible(true);
            fuzzy.compute();
        }
    }

    public void clickRbTFN() {
        if (rbTFN.getState () == false) {
            rbTFN.setState (true);
            clickedRbTFN();
        }
    }

    public void clickRbTrFN() {
        if (rbTrFN.getState () == false) {
            rbTrFN.setState (true);
            clickedRbTrFN();
        }
    }

    public void setValue (FuzzyNumber fn) {
        setEnabled(false);
        double x0, x1, x2, x3;
        x0 = fn.getLevel(0).getLower();
        x1 = fn.getLevel(FuzzyNumber.NOPL-1).getLower();
        x2 = fn.getLevel(FuzzyNumber.NOPL-1).getUpper();
        x3 = fn.getLevel(0).getUpper();
        if (x0 <= x1 && x1 <= x2 && x2 <= x3) {
            pv[0].setValue (x0);
            pv[1].setValue (x1);
            if (x1 == x2) { // TFN
                x2 = x3;
                x3 = max;
                clickRbTFN ();
            } else // TrFN
                clickRbTrFN ();
            pv[2].setValue (x2);
            pv[3].setValue (x3);
        }
        setEnabled(true);
    }

    public FuzzyNumber getValue () throws Exception {
        setEnabled(false);
        double x0, x1, x2;
        FuzzyNumber fn = null;
        x0 = pv[0].getValue ();
        x1 = pv[1].getValue ();
        x2 = pv[2].getValue ();
        if (pv[3].isVisible () == true) {
            double x3 = pv[3].getValue ();
            if (x0 <= x1 && x1 <= x2 && x2 <= x3)
                fn = new FuzzyNumber (x0, x1, x2, x3);
        } else if (x0 <= x1 && x1 <= x2)
            fn = new FuzzyNumber (x0, x1, x2);
        setEnabled(true);
        return fn;
    }
}

