/**
	14/05/2002
	@author		Bogdan Dorohonceanu
 */

package fn;

import java.awt.*;
import java.awt.image.*;

public class Picture extends Canvas {

    protected Container parent;
    protected Dimension minSize;
    protected int w, h, x0, y0, xMax, yMax, dx, dy, d = 30, c = 2;
    protected Polygon A1 = null, A2 = null;
    protected double sx;

    public Picture (Container parent, int initialWidth, int initialHeight) {
        this.parent = parent;
	    w = initialWidth;
	    h = initialHeight;
	    minSize = new Dimension(w,h);
	    x0 = d;
	    y0 = h - d;
	    xMax = w - d;
	    yMax = d;
	    dx = (xMax - x0) / 5;
	    dy = (yMax - y0) / 10;
	    sx = (xMax - x0) / 5.0;
        setFont (new Font("Dialog",Font.PLAIN,14));
        setBackground(Color.orange);
    }

    public Dimension getPreferredSize() {
     	return getMinimumSize();
    }

    public synchronized Dimension getMinimumSize() {
	    return minSize;
    }

    public void paint (Graphics g) {
        update (g);
    }

    public void update (Graphics g) {
        g.setColor (Color.black);
        g.drawRect (0,0,w - 1,h - 1);
        g.setColor(getBackground());
        g.fillRect(1, 1, w - 2, h - 2);
        drawAxes (g);
        if (A1 != null) {
            g.setColor (Color.red);
            g.drawString ("A1", w / 2 - 14, 16);
            g.drawPolygon (A1);
        }
        if (A2 != null) {
            g.setColor (Color.blue);
            g.drawString ("A2", w / 2 + 14, 16);
            g.drawPolygon (A2);
        }
    }

    public void drawAxes (Graphics g) {
        g.setColor (Color.black);
        g.drawLine (x0, y0, xMax + d / 2, y0);
        g.drawLine (xMax + d / 2 - c, y0 - c, xMax + d / 2, y0);
        g.drawLine (xMax + d / 2 - c, y0 + c, xMax + d / 2, y0);
        for (int i = 0; i <= 5; i ++ ) {
            g.drawLine (x0 + i * dx, y0 - c, x0 + i * dx, y0 + c);
            g.drawString ("" + i, x0 + i * dx, y0 + 3 * d / 4);
        }

        g.drawLine (x0, y0, x0, yMax - d / 2);
        g.drawLine (x0 - c, yMax - d / 2 + c, x0, yMax - d / 2);
        g.drawLine (x0 + c, yMax - d / 2 + c, x0, yMax - d / 2);
        int i;
        for (i = 0; i <= 9; i ++ ) {
            g.drawLine (x0 - c, y0 + i * dy, x0 + c, y0 + i * dy);
            g.drawString ("0." + i , x0 - 3 * d / 4, y0 + dy * i + 4);
        }
        g.drawLine (x0 - c, y0 + i * dy, x0 + c, y0 + i * dy);
        g.drawString ("1.0", x0 - 3 * d / 4, y0 + dy * i + 4);
    }

    public synchronized void setValues (FuzzyNumber a1, FuzzyNumber a2) {
        if (a1 == null || a2 == null ) {
            A1 = null;
            A2 = null;
            return;
        }

        int y[] = new int [4];
        y[0] = y[3] = y0;
        y[1] = y[2] = yMax;

        int x[] = new int [4];
        x[0] = d + (int) (sx * a1.getLevel(0).getLower ());
        x[1] = d + (int) (sx * a1.getLevel(FuzzyNumber.NOPL - 1).getLower ());
        x[2] = d + (int) (sx * a1.getLevel(FuzzyNumber.NOPL - 1).getUpper ());
        x[3] = d + (int) (sx * a1.getLevel(0).getUpper ());
        A1 = new Polygon (x, y, 4);

        x[0] = d + (int) (sx * a2.getLevel(0).getLower ());
        x[1] = d + (int) (sx * a2.getLevel(FuzzyNumber.NOPL - 1).getLower ());
        x[2] = d + (int) (sx * a2.getLevel(FuzzyNumber.NOPL - 1).getUpper ());
        x[3] = d + (int) (sx * a2.getLevel(0).getUpper ());
        A2 = new Polygon (x, y, 4);
    }
}

