/**
	14/05/2002
	@author		Bogdan Dorohonceanu
 */

package fn;

public class FuzzyNumber {

    public static int NOPL = 11; // number of presumption levels
    protected Interval levels[] = null;

    public FuzzyNumber (double x) throws Exception {
        this (x, x, x, x);
    }

    public FuzzyNumber (double bottom1, double top, double bottom2) throws Exception {
        this (bottom1, top, top, bottom2);
    }

    public FuzzyNumber (double bottom1, double top1, double top2, double bottom2) throws Exception {
        set (bottom1, top1, top2, bottom2);
    }


    public Interval getLevel (int i) {
        return levels[i];
    }

    private void set (double bottom1, double top1, double top2, double bottom2)
            throws Exception {
        if (levels == null)
            levels = new Interval [NOPL];
        if (levels != null) {
            double tmp1 = top1 - bottom1, tmp2 = bottom2 - top2, n = NOPL - 1.0;
            for ( int i = 0; i < NOPL; i++) {
                double tmp3 = i / n;
                levels[i] = new Interval (bottom1 + tmp1 * tmp3, bottom2 - tmp2 * tmp3);
            }
        }
    }

    public double greaterThan (FuzzyNumber fn) {
        return FuzzyNumber.greaterThan (this, fn);
    }

    public double lessThan (FuzzyNumber fn) {
        return FuzzyNumber.lessThan (this, fn);
    }

    public static double lessThan (FuzzyNumber a, FuzzyNumber b) {
	    double alpha = 0.0, m = 0.0;
	    for (int i = 0; i < NOPL; i++) {
    		double p = a.levels[i].length * b.levels[i].length;
    		m += p;
			alpha += p * Interval.lessThan(a.levels[i], b.levels[i]);
	    }
	    return ((m == 0.0) ? alpha : (alpha / m));
    }

    public static double greaterThan (FuzzyNumber a, FuzzyNumber b) {
	    double alpha = 0.0, m = 0.0;
	    for (int i = 0; i < NOPL; i++) {
    		double p = a.levels[i].length * b.levels[i].length;
    		m += p;
			alpha += p * Interval.greaterThan(a.levels[i], b.levels[i]);
	    }
	    return ((m == 0.0) ? alpha : (alpha / m));
    }

    public double mGreaterThan (FuzzyNumber fn) throws Exception {
        return FuzzyNumber.mGreaterThan (this, fn);
    }

    public double mLessThan (FuzzyNumber fn) throws Exception {
        return FuzzyNumber.mLessThan (this, fn);
    }

    public static double mLessThan (FuzzyNumber a, FuzzyNumber b) throws Exception {
	    double alpha = 0.0, m = 0.0;
	    FuzzyNumber a1 = new FuzzyNumber (a.levels[0].lower, a.levels[NOPL - 1].lower, a.levels[NOPL - 1].lower);
	    FuzzyNumber a2 = new FuzzyNumber (a.levels[NOPL - 1].lower, a.levels[NOPL - 1].lower, a.levels[NOPL - 1].upper, a.levels[NOPL - 1].upper);
	    FuzzyNumber a3 = new FuzzyNumber (a.levels[NOPL - 1].upper, a.levels[NOPL - 1].upper, a.levels[0].upper);
	    for (int i = 0; i < NOPL; i++) {
    		m += a.levels[i].length * b.levels[i].length;
    		alpha +=  b.levels[i].length * (a1.levels[i].length * Interval.lessThan(a1.levels[i], b.levels[i]) +
    		     	a2.levels[i].length * Interval.lessThan(a2.levels[i], b.levels[i]) +
    	         	a3.levels[i].length * Interval.lessThan(a3.levels[i], b.levels[i]));
	    }
	    return ((m == 0.0) ? alpha : (alpha / m));
    }

    public static double mGreaterThan (FuzzyNumber a, FuzzyNumber b) throws Exception {
	    double alpha = 0.0, m = 0.0;
	    FuzzyNumber a1 = new FuzzyNumber (a.levels[0].lower, a.levels[NOPL - 1].lower, a.levels[NOPL - 1].lower);
	    FuzzyNumber a2 = new FuzzyNumber (a.levels[NOPL - 1].lower, a.levels[NOPL - 1].lower, a.levels[NOPL - 1].upper, a.levels[NOPL - 1].upper);
	    FuzzyNumber a3 = new FuzzyNumber (a.levels[NOPL - 1].upper, a.levels[NOPL - 1].upper, a.levels[0].upper);
	    for (int i = 0; i < NOPL; i++) {
    		m += a.levels[i].length * b.levels[i].length;
    		alpha +=  b.levels[i].length *
    		    	(a1.levels[i].length * Interval.greaterThan(a1.levels[i], b.levels[i]) +
    				a2.levels[i].length * Interval.greaterThan(a2.levels[i], b.levels[i]) +
    	         	a3.levels[i].length * Interval.greaterThan(a3.levels[i], b.levels[i]));
	    }
	    return ((m == 0.0) ? alpha : (alpha / m));
    }
}

